==> aws-java-sdk-opsworks-1.11.30-sources.jar: com/amazonaws/services/opsworks/model/transform/GrantAccessResultJsonUnmarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not
 * use this file except in compliance with the License. A copy of the License is
 * located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.opsworks.model.transform;

import java.util.Map;
import java.util.Map.Entry;
import java.math.*;
import java.nio.ByteBuffer;

import com.amazonaws.services.opsworks.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * GrantAccessResult JSON Unmarshaller
 */
public class GrantAccessResultJsonUnmarshaller implements
        Unmarshaller<GrantAccessResult, JsonUnmarshallerContext> {

    public GrantAccessResult unmarshall(JsonUnmarshallerContext context)
            throws Exception {
        GrantAccessResult grantAccessResult = new GrantAccessResult();

        int originalDepth = context.getCurrentDepth();
        String currentParentElement = context.getCurrentParentElement();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.getCurrentToken();
        if (token == null)
            token = context.nextToken();
        if (token == VALUE_NULL)
            return null;

        while (true) {
            if (token == null)
                break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("TemporaryCredential", targetDepth)) {
                    context.nextToken();
                    grantAccessResult
                            .setTemporaryCredential(TemporaryCredentialJsonUnmarshaller
                                    .getInstance().unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getLastParsedParentElement() == null
                        || context.getLastParsedParentElement().equals(
                                currentParentElement)) {
                    if (context.getCurrentDepth() <= originalDepth)
                        break;
                }
            }
            token = context.nextToken();
        }

        return grantAccessResult;
    }

    private static GrantAccessResultJsonUnmarshaller instance;

    public static GrantAccessResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new GrantAccessResultJsonUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-opsworks-1.11.46-sources.jar: com/amazonaws/services/opsworks/model/transform/GrantAccessResultJsonUnmarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */
package com.amazonaws.services.opsworks.model.transform;

import java.util.Map;
import java.util.Map.Entry;
import java.math.*;
import java.nio.ByteBuffer;

import com.amazonaws.services.opsworks.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * GrantAccessResult JSON Unmarshaller
 */
public class GrantAccessResultJsonUnmarshaller implements Unmarshaller<GrantAccessResult, JsonUnmarshallerContext> {

    public GrantAccessResult unmarshall(JsonUnmarshallerContext context) throws Exception {
        GrantAccessResult grantAccessResult = new GrantAccessResult();

        int originalDepth = context.getCurrentDepth();
        String currentParentElement = context.getCurrentParentElement();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.getCurrentToken();
        if (token == null)
            token = context.nextToken();
        if (token == VALUE_NULL)
            return null;

        while (true) {
            if (token == null)
                break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("TemporaryCredential", targetDepth)) {
                    context.nextToken();
                    grantAccessResult.setTemporaryCredential(TemporaryCredentialJsonUnmarshaller.getInstance().unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getLastParsedParentElement() == null || context.getLastParsedParentElement().equals(currentParentElement)) {
                    if (context.getCurrentDepth() <= originalDepth)
                        break;
                }
            }
            token = context.nextToken();
        }

        return grantAccessResult;
    }

    private static GrantAccessResultJsonUnmarshaller instance;

    public static GrantAccessResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new GrantAccessResultJsonUnmarshaller();
        return instance;
    }
}
